package com.bonus.canteen.user.mapper;

import java.util.List;
import com.bonus.canteen.user.domain.UserFace;

/**
 * 人员生物识别特征Mapper接口
 * 
 * @author xsheng
 * @date 2025-04-03
 */
public interface UserFaceMapper {
    /**
     * 查询人员生物识别特征
     * 
     * @param faceId 人员生物识别特征主键
     * @return 人员生物识别特征
     */
    public UserFace selectUserFaceByFaceId(Long faceId);

    /**
     * 查询人员生物识别特征列表
     * 
     * @param UserFace 人员生物识别特征
     * @return 人员生物识别特征集合
     */
    public List<UserFace> selectUserFaceList(UserFace UserFace);

    /**
     * 新增人员生物识别特征
     * 
     * @param UserFace 人员生物识别特征
     * @return 结果
     */
    public int insertUserFace(UserFace UserFace);

    /**
     * 修改人员生物识别特征
     * 
     * @param UserFace 人员生物识别特征
     * @return 结果
     */
    public int updateUserFace(UserFace UserFace);

    /**
     * 删除人员生物识别特征
     * 
     * @param faceId 人员生物识别特征主键
     * @return 结果
     */
    public int deleteUserFaceByFaceId(Long faceId);

    /**
     * 批量删除人员生物识别特征
     * 
     * @param faceIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteUserFaceByFaceIds(Long[] faceIds);
}
