package com.bonus.canteen.user.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.canteen.user.domain.UserFace;
import com.bonus.canteen.user.service.IUserFaceService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 人员生物识别特征Controller
 * 
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "人员生物识别特征接口")
@RestController
@RequestMapping("/sys_user_face")
public class UserFaceController extends BaseController {
    @Autowired
    private IUserFaceService UserFaceService;

    /**
     * 查询人员生物识别特征列表
     */
    @ApiOperation(value = "查询人员生物识别特征列表")
    //@RequiresPermissions("system:face:list")
    @GetMapping("/list")
    public TableDataInfo list(UserFace UserFace) {
        startPage();
        List<UserFace> list = UserFaceService.selectUserFaceList(UserFace);
        return getDataTable(list);
    }

    /**
     * 导出人员生物识别特征列表
     */
    @ApiOperation(value = "导出人员生物识别特征列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("system:face:export")
    @SysLog(title = "人员生物识别特征", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出人员生物识别特征")
    @PostMapping("/export")
    public void export(HttpServletResponse response, UserFace UserFace) {
        List<UserFace> list = UserFaceService.selectUserFaceList(UserFace);
        ExcelUtil<UserFace> util = new ExcelUtil<UserFace>(UserFace.class);
        util.exportExcel(response, list, "人员生物识别特征数据");
    }

    /**
     * 获取人员生物识别特征详细信息
     */
    @ApiOperation(value = "获取人员生物识别特征详细信息")
    //@RequiresPermissions("system:face:query")
    @GetMapping(value = "/{faceId}")
    public AjaxResult getInfo(@PathVariable("faceId") Long faceId) {
        return success(UserFaceService.selectUserFaceByFaceId(faceId));
    }

    /**
     * 新增人员生物识别特征
     */
    @ApiOperation(value = "新增人员生物识别特征")
    //@PreventRepeatSubmit
    //@RequiresPermissions("system:face:add")
    @SysLog(title = "人员生物识别特征", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增人员生物识别特征")
    @PostMapping
    public AjaxResult add(@RequestBody UserFace UserFace) {
        try {
            return toAjax(UserFaceService.insertUserFace(UserFace));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改人员生物识别特征
     */
    @ApiOperation(value = "修改人员生物识别特征")
    //@PreventRepeatSubmit
    //@RequiresPermissions("system:face:edit")
    @SysLog(title = "人员生物识别特征", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改人员生物识别特征")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody UserFace UserFace) {
        try {
            return toAjax(UserFaceService.updateUserFace(UserFace));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除人员生物识别特征
     */
    @ApiOperation(value = "删除人员生物识别特征")
    //@PreventRepeatSubmit
    //@RequiresPermissions("system:face:remove")
    @SysLog(title = "人员生物识别特征", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除人员生物识别特征")
	@PostMapping("/del/{faceIds}")
    public AjaxResult remove(@PathVariable Long[] faceIds) {
        return toAjax(UserFaceService.deleteUserFaceByFaceIds(faceIds));
    }
}
